@@ -1,12 +1,11 @@
 import inspect
-from typing import Any, Dict, Union
+from typing import Any, Dict, Optional, Union
 
 from rich.console import Console
 from rich.highlighter import ReprHighlighter
 from rich.syntax import Syntax
 from rich.text import Text
 
-
 highlighter = ReprHighlighter()
 
 
@@ -20,11 +19,13 @@ class CachedObject:
     def __init__(
         self,
         obj: Any,
-        dotpath: str,
+        dotpath: str = "",
+        attr_name=None,
     ):
         self.obj = obj
-        self.is_callable = callable(obj)
         self.dotpath = dotpath
+        self.attr_name = attr_name
+        self.is_callable = callable(obj)
         self.selected_cached_obj: CachedObject
 
         self.typeof: Text = highlighter(str(type(self.obj)))
@@ -32,6 +33,9 @@ class CachedObject:
 
         self.plain_attrs = dir(self.obj)
 
+        self.repr = highlighter(repr(self.obj))
+        self.repr.overflow = "ellipsis"
+
         if "__weakref__" in self.plain_attrs:
             # Ignore weakrefs
             self.plain_attrs.remove("__weakref__")
@@ -42,6 +46,16 @@ class CachedObject:
         self.plain_private_attributes = sorted(
             attr for attr in self.plain_attrs if attr.startswith("_")
         )
+        self.public_attribute_width = (
+            max(map(len, self.plain_public_attributes))
+            if self.plain_public_attributes
+            else 0
+        )
+        self.private_attribute_width = (
+            max(map(len, self.plain_private_attributes))
+            if self.plain_private_attributes
+            else 0
+        )
         # Key:val pair of attribute name and the cached object associated with it
         self.cached_attributes: Dict[str, CachedObject] = {}
 
@@ -50,12 +64,21 @@ class CachedObject:
         except Exception:
             self._source = ""
 
+        self.length: Optional[str]
+
+        try:
+            self.length = str(len(self.obj))
+        except TypeError:
+            self.length = None
+
     def cache_attributes(self):
         """ Create a CachedObject for each attribute of the self.obj """
         if not self.cached_attributes:
             for attr in self.plain_attrs:
                 self.cached_attributes[attr] = CachedObject(
-                    getattr(self.obj, attr), dotpath=f"{self.dotpath}.{attr}"
+                    getattr(self.obj, attr),
+                    dotpath=f"{self.dotpath}.{attr}",
+                    attr_name=attr,
                 )
 
         # Set the default selected cached attribute
@@ -92,7 +115,3 @@ class CachedObject:
                 line_range=(0, term_height),
                 background_color="default",
             )
-
-    @property
-    def display_name(self) -> str:
-        return f"{self.parent_name}.{self.name}" if self.name else repr(self.obj)
